# What

iprestriction based on django-fast-ratelimit (therefor the name: django-fast-iprestrict)

# settings

IPRESTRICT_DEFAULT_ACTION: allow/deny : default action when no rule matches, default, when not set allow

# TODO

-   tests
-   docs
-   cleanup
